#!/usr/bin/env python3

"""
Утилита конфигурирования resolv.conf
"""
import os
import subprocess
import sys
import lsb_release
sys.path.append("/linuxcash/cash/tools/tools_avail")
from dialog import Dialog
from py_tools.logger import logger

log = logger.Logger()

is_trusty_tuhr = lsb_release.get_distro_information()['RELEASE'] == '14.04'
if is_trusty_tuhr:
    resolf_conf_file = "/etc/resolvconf/resolv.conf.d/base"
else:
    resolf_conf_file = "/etc/resolv.conf"
tmp_resolf_conf_file = "/tmp/resolv.conf"


def main():
    log.info("Изменение списка DNS серверов")
    run = True
    try:
        d = Dialog()
        d.add_persistent_args(("--backtitle", "Изменить список DNS серверов"))
        log.info("Копирование файла %s" % resolf_conf_file + " во временный файл %s" % tmp_resolf_conf_file)
        subprocess.call("cp " + resolf_conf_file + " " + tmp_resolf_conf_file, shell = True)

        if not os.path.exists(tmp_resolf_conf_file):
            log.info("Копирование не удалось. Создание файла %s" % tmp_resolf_conf_file)
            subprocess.call("touch " + tmp_resolf_conf_file, shell = True)
            firstFile = open(tmp_resolf_conf_file, 'w')
            log.info("Запись значения 'nameserver 192.168.0.1' в файл %s" % tmp_resolf_conf_file)
            firstFile.write("nameserver 192.168.0.1\n")
            firstFile.close()
            log.info("Адрес сервера успешно записан")

        while run:
            log.info("Открытие файла %s" % tmp_resolf_conf_file + " для потоковой записи")
            code, text = d.editbox(filepath=tmp_resolf_conf_file, title="Шаг 1: Изменить список DNS",
                        ok_label="Далее", cancel_label="Закрыть", width=60, height=20,)
            
            if code == d.OK:
                with open(tmp_resolf_conf_file, 'w') as tmpFile:
                    tmpFile.write(text)
                code = d.msgbox(
                    text,
                    width=60,
                    height=12,
                    title = "Шаг 2: Завершение настройки",
                    ok_label = "Завершить",
                    help_button = "enable",
                    help_label = "Назад"
                )
                if code == d.OK:
                    log.info("Перемещение файла %s" % tmp_resolf_conf_file + " в файл %s" % resolf_conf_file)
                    retCode = subprocess.call("sudo mv " + tmp_resolf_conf_file + " " + resolf_conf_file, shell=True)
                    if not retCode and is_trusty_tuhr:
                        retCode = subprocess.call("sudo resolvconf -u",shell=True)
                    if not retCode:
                        log.info("Настройки успешно сохранены")
                        d.msgbox("Настройки успешно сохранены", height = 6)
                        run = False
                    else:
                        log.error("Не удалось сохранить настройки")
                        d.msgbox("Не удалось сохранить настройки", height = 6)
            else:
                if code != d.CANCEL:
                    log.error("Не удалось открыть файл %s" % tmp_resolf_conf_file)
                run = False
        log.info("Удаление временного файла %s" % tmp_resolf_conf_file)
        subprocess.call("rm " + tmp_resolf_conf_file, shell = True)
    except KeyboardInterrupt:
        log.info("Удаление временного файла %s" % tmp_resolf_conf_file)
        subprocess.call("rm " + tmp_resolf_conf_file, shell = True)
        log.info("Неожиданное завершение изменения списка DNS серверов")
        exit(0)

if __name__ == "__main__":
    os.chdir(os.path.dirname(os.path.abspath(__file__)))
    main()

